@@ -211,6 +211,25 @@ Profile::create(const SpatialReference* srs)
     }
 }
 
+const Profile*
+Profile::create(const GeoExtent& extent)
+{
+    OE_SOFT_ASSERT_AND_RETURN(extent.isValid(), nullptr);
+
+    unsigned tx = 1, ty = 1;
+    float ar = (float)extent.width() / (float)extent.height();
+    if (ar > 1.5f)
+    {
+        tx = (unsigned)::ceil(ar);
+    }
+    else if (ar < 0.5f)
+    {
+        ty = (unsigned)::ceil(1.0f / ar);
+    }
+
+    return create(extent.getSRS(), extent.xMin(), extent.yMin(), extent.xMax(), extent.yMax(), tx, ty);
+}
+
 const Profile*
 Profile::create(const SpatialReference* srs,
                 double xmin, double ymin, double xmax, double ymax,
@@ -361,13 +380,11 @@ Profile::create_with_vdatum(const std::string& name, const std::string& vsrsStri
 {
     if ( ciEquals(name, PLATE_CARREE) || ciEquals(name, "plate-carre") || ciEquals(name, "eqc-wgs84") )
     {
-        // Yes I know this is not really Plate Carre but it will stand in for now.
         osg::Vec3d ex;
         const SpatialReference* plateCarre = SpatialReference::get("plate-carre", vsrsString);
         const SpatialReference* wgs84 = SpatialReference::get("wgs84", vsrsString);
-        wgs84->transform(osg::Vec3d(180,90,0), plateCarre, ex);
-
-        return Profile::create(PLATE_CARREE, plateCarre, -ex.x(), -ex.y(), ex.x(), ex.y(), 2u, 1u);
+        wgs84->transform(osg::Vec3d(-180,-90,0), plateCarre, ex);
+        return Profile::create(PLATE_CARREE, plateCarre, ex.x(), ex.y(), -ex.x(), -ex.y(), 2u, 1u);
     }
     else if (ciEquals(name, GLOBAL_GEODETIC))
     {
